@@ -4,9 +4,10 @@ from canalyst_candas.candas import (
     ModelMap,
     ModelSet,
     Chart,
+    Search,
     SampleModel,
 )
-from canalyst_candas.utils import get_chart_brand_config
+from canalyst_candas.utils.transformations import get_chart_brand_config
 from canalyst_candas.datafunctions import DataFunctions
 import canalyst_candas.version as version
 
