@@ -76,7 +76,7 @@ class Config(object):
         self.default_dir = config.get("default_dir") or settings.DEFAULT_DIR
         self.mds_host = config.get("mds_host") or settings.MDS_HOST
         self.wp_host = config.get("wp_host") or settings.WP_HOST
-        self.verify_ssl = config.get("verify_ssl") or True
+        self.verify_ssl = config.get("verify_ssl", True)
 
 
 class ConfigProvider(object):
